==> nextcloud-23.0.12p1.tgz: nextcloud/apps/sharebymail/l10n/nb.js <==
OC.L10N.register(
    "sharebymail",
    {
    "Shared with %1$s" : "Delt med %1$s",
    "Shared with {email}" : "Delt med {email}",
    "Shared with %1$s by %2$s" : "Delt med %1$s via %2$s",
    "Shared with {email} by {actor}" : "Delt med {email} av {actor}",
    "Password for mail share sent to %1$s" : "Passord for e-postlager sendt til %1$s",
    "Password for mail share sent to {email}" : "Passord for e-postlager sendt til {email}",
    "Password for mail share sent to you" : "Passord for e-postlager sendt til deg",
    "You shared %1$s with %2$s by mail" : "Du delte %1$s med %2$s via e-post",
    "You shared {file} with {email} by mail" : "Du delte {file} med {email} via e-post",
    "%3$s shared %1$s with %2$s by mail" : "%3$s delte %1$s med %2$s via e-post",
    "{actor} shared {file} with {email} by mail" : "{actor} delte {file} med {email} via e-post",
    "You unshared %1$s from %2$s by mail" : "Du opphevde delingen %1$s med %2$s via e-post",
    "You unshared {file} from {email} by mail" : "Du opphevde delingen {file} med {email} via e-post",
    "Password to access %1$s was sent to %2s" : "Passord for tilgang til %1$s sendt til %2s",
    "Password to access {file} was sent to {email}" : "Passord for tilgang til {file} ble sendt til {email}",
    "Password to access %1$s was sent to you" : "Passord for tilgang til %1$s ble sendt til deg",
    "Password to access {file} was sent to you" : "Du ble tildelt passord for å benytte {file}",
    "Share by mail" : "Del via e-post",
    "Failed to send share by email" : "Delingen kunne ikke sendes med e-post",
    "%1$s shared »%2$s« with you" : "%1$s delte »%2$s« med deg",
    "%1$s shared »%2$s« with you." : "%1$s delte »%2$s« med deg.",
    "Click the button below to open it." : "Klikk på knappen nedenfor for å åpne den.",
    "Open »%s«" : "Åpne »%s«",
    "%1$s via %2$s" : "%1$s via %2$s",
    "Password to access »%s«" : "Passord for å benytte »%s«",
    "It is protected with the following password:" : "Den er beskyttet med følgende passord:",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s delte »%2$s« med deg og vil legge til:",
    "%1$s shared »%2$s« with you and wants to add" : "%1$s delte »%2$s« med deg og vil legge til",
    "»%s« added a note to a file shared with you" : "»%s« la til en melding til en fil delt med deg",
    "Password to access »%1$s« shared by you with %2$s" : "Passord for å få tilgang til »%1$s« delt av deg med %2$s",
    "This is the password:" : "Dette er passordet:",
    "You can choose a different password at any time in the share dialog." : "Du kan velge et annet passord når som helst i delingsdialogvinduet.",
    "Could not find share" : "Delingen ble ikke funnet",
    "Allows users to share a personalized link to a file or folder by putting in an email address." : "Tillater brukere å dele en personalisert lenke til ei fil eller mappe ved å skrive inn en e-postadresse.",
    "Send password by mail" : "Send passord via e-post"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-24.0.10.tgz: nextcloud/apps/sharebymail/l10n/nb.js <==
OC.L10N.register(
    "sharebymail",
    {
    "Shared with {email}" : "Delt med {email}",
    "Shared with {email} by {actor}" : "Delt med {email} av {actor}",
    "Password for mail share sent to {email}" : "Passord for e-postlager sendt til {email}",
    "Password for mail share sent to you" : "Passord for e-postlager sendt til deg",
    "You shared {file} with {email} by mail" : "Du delte {file} med {email} via e-post",
    "{actor} shared {file} with {email} by mail" : "{actor} delte {file} med {email} via e-post",
    "You unshared {file} from {email} by mail" : "Du opphevde delingen {file} med {email} via e-post",
    "Password to access {file} was sent to {email}" : "Passord for tilgang til {file} ble sendt til {email}",
    "Password to access {file} was sent to you" : "Du ble tildelt passord for å benytte {file}",
    "Share by mail" : "Del via e-post",
    "Failed to send share by email" : "Delingen kunne ikke sendes med e-post",
    "%1$s shared »%2$s« with you" : "%1$s delte »%2$s« med deg",
    "%1$s shared »%2$s« with you." : "%1$s delte »%2$s« med deg.",
    "Click the button below to open it." : "Klikk på knappen nedenfor for å åpne den.",
    "Open »%s«" : "Åpne »%s«",
    "%1$s via %2$s" : "%1$s via %2$s",
    "Password to access »%s«" : "Passord for å benytte »%s«",
    "It is protected with the following password:" : "Den er beskyttet med følgende passord:",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s delte »%2$s« med deg og vil legge til:",
    "%1$s shared »%2$s« with you and wants to add" : "%1$s delte »%2$s« med deg og vil legge til",
    "»%s« added a note to a file shared with you" : "»%s« la til en melding til en fil delt med deg",
    "Password to access »%1$s« shared by you with %2$s" : "Passord for å få tilgang til »%1$s« delt av deg med %2$s",
    "This is the password:" : "Dette er passordet:",
    "You can choose a different password at any time in the share dialog." : "Du kan velge et annet passord når som helst i delingsdialogvinduet.",
    "Could not find share" : "Delingen ble ikke funnet",
    "Allows users to share a personalized link to a file or folder by putting in an email address." : "Tillater brukere å dele en personalisert lenke til ei fil eller mappe ved å skrive inn en e-postadresse.",
    "Send password by mail" : "Send passord via e-post",
    "Shared with %1$s" : "Delt med %1$s",
    "Shared with %1$s by %2$s" : "Delt med %1$s via %2$s",
    "Password for mail share sent to %1$s" : "Passord for e-postlager sendt til %1$s",
    "You shared %1$s with %2$s by mail" : "Du delte %1$s med %2$s via e-post",
    "%3$s shared %1$s with %2$s by mail" : "%3$s delte %1$s med %2$s via e-post",
    "You unshared %1$s from %2$s by mail" : "Du opphevde delingen %1$s med %2$s via e-post",
    "Password to access %1$s was sent to %2s" : "Passord for tilgang til %1$s sendt til %2s",
    "Password to access %1$s was sent to you" : "Passord for tilgang til %1$s ble sendt til deg"
},
"nplurals=2; plural=(n != 1);");
